@@ -1,7 +1,7 @@
 package Proc::Govern;
 
 our $DATE = '2019-05-23'; # DATE
-our $VERSION = '0.206'; # VERSION
+our $VERSION = '0.207'; # VERSION
 
 use 5.010001;
 use strict;
@@ -637,7 +637,7 @@ Proc::Govern - Run child process and govern its various aspects
 
 =head1 VERSION
 
-This document describes version 0.206 of Proc::Govern (from Perl distribution Proc-Govern), released on 2019-05-23.
+This document describes version 0.207 of Proc::Govern (from Perl distribution Proc-Govern), released on 2019-05-23.
 
 =head1 SYNOPSIS
 
@@ -995,13 +995,22 @@ feature.
 
 =head1 SEE ALSO
 
-Proc::Govern uses L<IPC::Run> at its core.
+L<Forks::Super> (since 2009) extends the fork(), wait(), and waitpid() functions
+with some process/job management features, e.g. set timeout, retries, chdir,
+environment, umask, delay before start, control STDIN/STDOUT/STDERR, load
+control, priority/nice level, daemon, and a lot more. Had I known about this
+module, I probably wouldn't start Proc::Govern.
 
-L<IPC::Cmd> also uses IPC::Run (as well as L<IPC::Open3> on systems that do not
-have IPC::Run installed or on some archaic systems that do not support IPC::Run)
-and its C<run_forked()> routine also has some of Proc::Govern's functionalities
-like capturing stdout and stderr, timeout, hiding (discarding) output. If you
-only need those functionalities, you can use IPC::Cmd as it is a core module.
+Proc::Govern uses L<IPC::Run> at its core; you might want to use it directly. It
+already has some features, e.g. controlling STDIN/STDOUT/STDERR and timeout. But
+the main selling point of IPC::Run is its redirection and piping features.
+
+L<IPC::Cmd> is a core module, but can also use IPC::Run (as well as
+L<IPC::Open3> on systems that do not have IPC::Run installed or on some archaic
+systems that do not support IPC::Run). Its C<run_forked()> routine has some of
+Proc::Govern's functionalities like capturing stdout and stderr, timeout, hiding
+(discarding) output. If you only need those functionalities, you can use
+IPC::Cmd as it is a core module.
 
 Proc::Govern attempts (or will attempt, some day) to provide the functionality
 (or some of the functionality) of the builtins/modules/programs listed below:
